# Examples and tasks

These are real-world examples and tasks.

The notebooks do **not** get executed in CI for testing because they involve large data.

```{toctree}
:maxdepth: 1
:glob:
:reversed:

*
```
